Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(83)

Unified Diff: chrome/browser/resources/settings/people_page/lock_screen.js

Issue 2862613003: md settings: Show lock screen when pin/fingerprint disabled. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/people_page/lock_screen.js
diff --git a/chrome/browser/resources/settings/people_page/lock_screen.js b/chrome/browser/resources/settings/people_page/lock_screen.js
index f0ea062cd01b67e9b2de2cf9296b0b0dc28ae915..a5a9a65278bfc027f4d5f81c117eabea0a85c316 100644
--- a/chrome/browser/resources/settings/people_page/lock_screen.js
+++ b/chrome/browser/resources/settings/people_page/lock_screen.js
@@ -56,10 +56,10 @@ Polymer({
},
/**
* True if pin unlock settings should be displayed on this machine.
* @private
*/
- pinUnlockEnabled_: {
+ quickUnlockEnabled_: {
type: Boolean,
value: function() {
return loadTimeData.getBoolean('pinUnlockEnabled');
@@ -56,10 +56,10 @@ Polymer({
},
/**
- * True if pin unlock settings should be displayed on this machine.
+ * True if quick unlock settings should be displayed on this machine.
* @private
*/
jdufault 2017/05/04 21:03:45 You should rename the load time data as well.
sammiequon 2017/05/04 23:32:34 Done.

Powered by Google App Engine
This is Rietveld 408576698